import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import {Head, router} from '@inertiajs/react';
import { usePage } from '@inertiajs/react';
import {columns} from './Column'
import {LineItem, PaginatedData} from '@/types';
import { DataTable } from '@/Components/DataTable';
import {Input} from "@/Components/ui/input";
import {useCallback, useState} from "react";
import {ChangeEvent} from "react";
import { useSearchParam} from 'react-use';
import { PageProps } from '@/types';
import { User } from '@/types';
import { Config } from 'ziggy-js';
import {
    Select,
    SelectContent,
    SelectItem,
    SelectTrigger,
    SelectValue,
  } from "@/Components/ui/select"


interface LocalPageProps extends PageProps {
    lineItems: PaginatedData<LineItem>;
  }
export default function Index() {
    const { lineItems } = usePage<LocalPageProps>().props;
    // const { lineItems, auth, flash, ziggy } = usePage<{ lineItems: PaginatedData<LineItem>,
    //     auth: { user: User; agency_name: string; can: string[]; guard: string },
    //     flash: { success: string | null; error: string | null },
    //     ziggy: Config & { location: string } }>().props;


    const dateRanges = [
        { 'value': 'TODAY' },
        { 'value': 'YESTERDAY' },
        { 'value': 'LAST_WEEK' },
        { 'value': 'LAST_MONTH' },
        { 'value': 'LAST_3_MONTHS' },
        { 'value': 'REACH_LIFETIME' }
    ];
    const params = useSearchParam('search');

    const [originParam, setOriginParam] = useState(params ?? '')

    const searchSites = useCallback((e:ChangeEvent<HTMLInputElement>) => {
        setOriginParam(e.target.value)
        const currentRoute = route().current();
        const search = new URLSearchParams(window.location.search).get('search');
        const dateRange = new URLSearchParams(window.location.search).get('date_range');
        const request: { search?: string; date_range?: string | null } = {};
        if (e.target.value) {
            request.search = e.target.value;
        }
        if (dateRange) {
            request.date_range = dateRange;
        }

        if (currentRoute) {
          router.get(currentRoute, {
            search: e.target.value,
            date_range: dateRange
          }, {
            replace: true,
            preserveState: true,
          });
        } else {
          // Handle the case where the current route is undefined (fallback to a default route or show an error)
          console.error("Current route is undefined");
        }
    }, [originParam]);
    return (
        <AuthenticatedLayout>
            <Head title="Line Items" />

            <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 m-5">
                <div className={'flex justify-between  p-3'}>

                    <div className={"pb-5 text-2xl font-bold"}>
                        <strong>Line Items</strong>
                    </div>
                    <div>
                        <div className={'flex mx-4 gap-2'}>

                            <Select onValueChange={(value) => {
                                const currentRoute = route().current();
                                if (currentRoute) {
                                    router.get(currentRoute, {
                                        search: originParam,
                                        date_range: value
                                    }, {
                                        replace: true,
                                        preserveState: true,
                                    });
                                }
                            }}>
                                <SelectTrigger className="w-[180px]">
                                    <SelectValue placeholder="Select Date Range" />
                                </SelectTrigger>
                                <SelectContent>
                                    { dateRanges.map((item) => (
                                        <SelectItem key={item.value} value={item.value}>
                                            {item.value}
                                        </SelectItem>
                                    ))}
                                </SelectContent>
                            </Select>



                            <Input placeholder={'Search'}
                                onChange={searchSites}
                                value={originParam}
                            ></Input>
                        </div>

                    </div>
                </div>
                <DataTable columns={columns} data={lineItems.data} />
            </div>

        </AuthenticatedLayout>
    );
}
